/**
 * Returns a function which takes an unknown input, and returns `true` if the
 * input is a string which conforms to the provided `regexArg` pattern(s).
 *
 * Implementation note: the `RegExp.prototype.test()` method does not throw an
 * error if the input is not a string, so it's unnecessary to check the input
 * type, hence the `as string` type casts.
 */
export const getValidatorFn = (regexArg) => {
    return Object.assign(Array.isArray(regexArg)
        ? (value) => regexArg.every((regex) => regex.test(value))
        : (value) => regexArg.test(value), { _regex: regexArg });
};
